
# Slot: node_list_separator


The separator to use for the nodes file. Note that if this is not provided, one will be automatically detected among the following - comma, semi-column, tab and space.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_list_separator](https://w3id.org/neat/ensmallenRunConfig__node_list_separator)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
